server: www.livejournal.com
postcgi: /interface/flat
user: yourusername
password: yourpassword
community:

base dir: %s/.jlj
backup: yes no

editor offset: +16

security: public private friends prompt
format: preformatted none jerry
mood prompt: yes no
music prompt: yes no
picture prompt: yes no
community prompt: yes no
backdate entry: no yes prompt
allow comments: yes no prompt

proxy: no yes
proxy host: yourproxy.dom.tld
proxy port: 80
